<?php

namespace Teknisa\CNC\Services;

use Teknisa\CNC\Factories\Cnc01700ParametrizacaoProdutoFactory;
use Teknisa\CNC\Utilities;
use Teknisa\Libs\Util\Environment;


class Cnc01700ParametrizacaoProdutoService extends \Teknisa\CNC\Controllers\TeknisaCrud {
    
    protected $entityManager;
    protected $factory;
	protected $util;

    public function __construct(\Doctrine\ORM\EntityManager $entityManager, Cnc01700ParametrizacaoProdutoFactory $factory, Utilities\UtilCNC $util) {
        $this->entityManager = $entityManager;
        $this->factory = $factory;
        $this->util = $util;

    }

   
    public function saveCliente($params){
        if($params["DSTPDEBIBANC"] == null){
            $params["CDTPDEBIBANC"] = null;
        }
        $result = $this->factory->saveCliente(array(
            ":CDCLIENTE"        => $params["CDCLIENTE"],
            ":CDTPDBDEBGER"     => $params["CDTPDEBIBANC"],
            ":CDTPCREDBANCGER"  => $params["CDTPCREDBANC"],
            ":NRADQUIRENTE"     => $params["NRADQUIRENTE"],
            ":NRORG"            => $params["NRORG"],
            ":IDGERAFINANC"     => $params["IDGERAFINANC"]
        ));
        
        return $result;
        
    }
    
    public function produtoTab($params) {
        $result = $this->factory->produtoTab(array(
            ":NRORG"        => $params[0]["value"],
            ":NRADQUIRENTE" => $params[1]["value"],
            ":ALL_FIELDS"   => isset($params[2]) ? str_replace('%', '', $params[2]["value"][0]['_ALL']) : null,
            ":TALL_FIELDS"  => isset($params[2]) ? 'F' : 'T',
        ));
        return $result;
    }
    
    public function saveNewProdutoParams($params){
        $NRPARAMFINADQ = $this->util->newCode('NRPARAMFINADQ', '10');
        $NRPARAMFINADQ = intval($NRPARAMFINADQ);
        $params["NRPARAMFINADQ"] = $NRPARAMFINADQ;
        $params["NRESTABELEC"] = null;
        $exist = $this->findProdutoExist($params);
        
        if(count($exist) == 0){
            $result = $this->factory->saveNewProdutoParams(array(
                ":NRPARAMFINADQ"     => $params["NRPARAMFINADQ"],
                ":NRADQUIRENTE"         => $params["NRADQUIRENTE"],
                ":NRPRODUTOADQ"         => $params["NRPRODUTOADQ"],
                ":NRESTABELEC"          => $params["NRESTABELEC"],
                ":CDTPCTRECEB"          => $params["CDTPCTRECEB"],
                ":CDAJUCTREC"           => $params["CDAJUCTREC"],
                ":CDTIPOOPER"           => $params["CDTIPOOPER"],
                ":IDENTRSAIDOP"         => $params["IDENTRSAIDOP"],
                ":CDTPCREDBANC"         => $params["CDTPCREDBANC"],
                ":NRORG"                => $params["NRORG"],
                ":CDTPDEBIBANC"         => $params["CDTPDEBIBANC"]
            ));
        }else{
            $result = 1;
        }
        return $result;
    }
    
    public function saveNewEstabelecParams($params){
        
        $NRPARAMFINADQ = $this->util->newCode('NRPARAMFINADQ', '10');
        $NRPARAMFINADQ = intval($NRPARAMFINADQ);
        $params["NRPARAMFINADQ"] = $NRPARAMFINADQ;
        $exist = $this->findEstabelecExist($params);
        if(count($exist) == 0){
            $result = $this->factory->saveNewEstabelecParams(array(
                ":NRPARAMFINADQ"     => $params["NRPARAMFINADQ"],
                ":NRADQUIRENTE"         => $params["NRADQUIRENTE"],
                ":NRPRODUTOADQ"         => $params["NRPRODUTOADQ"],
                ":NRESTABELEC"          => $params["NRESTABELEC"],
                ":CDTPCTRECEB"          => $params["CDTPCTRECEB"],
                ":CDAJUCTREC"           => $params["CDAJUCTREC"],
                ":CDTIPOOPER"           => $params["CDTIPOOPER"],
                ":IDENTRSAIDOP"         => $params["IDENTRSAIDOP"],
                ":CDTPCREDBANC"         => $params["CDTPCREDBANC"],
                ":NRORG"                => $params["NRORG"],
                ":CDTPDEBIBANC"         => $params["CDTPDEBIBANC"]
            ));
        }else{
            $result = 1;
        }
        return $result;
    }
    
    public function saveProdutoParamsEdit($params){
        
        $result = $this->factory->saveProdutoParamsEdit(array(
            ":NRPARAMFINADQ"     => $params["NRPARAMFINADQ"],
            ":NRADQUIRENTE"         => $params["NRADQUIRENTE"],
            ":NRPRODUTOADQ"         => $params["NRPRODUTOADQ"],
            ":CDTPCTRECEB"          => $params["CDTPCTRECEB"],
            ":CDAJUCTREC"           => $params["CDAJUCTREC"],
            ":CDTIPOOPER"           => $params["CDTIPOOPER"],
            ":IDENTRSAIDOP"         => $params["IDENTRSAIDOP"],
            ":CDTPCREDBANC"         => $params["CDTPCREDBANC"],
            ":NRORG"                => $params["NRORG"],
            ":CDTPDEBIBANC"         => $params["CDTPDEBIBANC"]
            
        ));
        return $result;
    }

    public function saveProdutoParamsEditProd($params){

        $exist = $this->findProdutoExist($params);
        if(count($exist) == 0){
            $this->deleteEstabelecFromProdutoEdit($params);
            $result = $this->factory->saveProdutoParamsEdit(array(
                ":NRPARAMFINADQ"     => $params["NRPARAMFINADQ"],
                ":NRADQUIRENTE"         => $params["NRADQUIRENTE"],
                ":NRPRODUTOADQ"         => $params["NRPRODUTOADQ"],
                ":CDTPCTRECEB"          => $params["CDTPCTRECEB"],
                ":CDAJUCTREC"           => $params["CDAJUCTREC"],
                ":CDTIPOOPER"           => $params["CDTIPOOPER"],
                ":IDENTRSAIDOP"         => $params["IDENTRSAIDOP"],
                ":CDTPCREDBANC"         => $params["CDTPCREDBANC"],
                ":NRORG"                => $params["NRORG"],
                ":CDTPDEBIBANC"         => $params["CDTPDEBIBANC"]
                
            ));
        }else{
            $result = 1;
        }
        return $result;
    }
    
    public function editEstabelec($params){

        $result = $this->factory->editEstabelec(array(
            ":NRADQUIRENTE"         => $params["NRADQUIRENTE"],
            ":NRPRODUTOADQ"         => $params["NRPRODUTOADQ"],
            ":NRESTABELEC"          => $params["NRESTABELEC"],
            ":CDTPCTRECEB"          => $params["CDTPCTRECEB"],
            ":CDAJUCTREC"           => $params["CDAJUCTREC"],
            ":CDTIPOOPER"           => $params["CDTIPOOPER"],
            ":CDTPCREDBANC"         => $params["CDTPCREDBANC"],
            ":NRESTABELECANT"       => $params["NRESTABELECANT"],
            ":NRORG"                => $params["NRORG"],
            ":IDENTRSAIDOP"         => $params["IDENTRSAIDOP"],
            ":CDTPDEBIBANC"         => $params["CDTPDEBIBANC"]
        ));

        return $result;
    }
    
    public function editNewEstabelec($params){

        $exist = $this->findEstabelecExist($params);
        if(count($exist) == 0){
            $result = $this->factory->editEstabelec(array(
                ":NRADQUIRENTE"         => $params["NRADQUIRENTE"],
                ":NRPRODUTOADQ"         => $params["NRPRODUTOADQ"],
                ":NRESTABELEC"          => $params["NRESTABELEC"],
                ":CDTPCTRECEB"          => $params["CDTPCTRECEB"],
                ":CDAJUCTREC"           => $params["CDAJUCTREC"],
                ":CDTIPOOPER"           => $params["CDTIPOOPER"],
                ":CDTPCREDBANC"         => $params["CDTPCREDBANC"],
                ":NRESTABELECANT"       => $params["NRESTABELECANT"],
                ":NRORG"                => $params["NRORG"],
                ":IDENTRSAIDOP"         => $params["IDENTRSAIDOP"],
                ":CDTPDEBIBANC"         => $params["CDTPDEBIBANC"]
            ));
        }else{
            $result = 1;
        }
        return $result;
    }

    
    public function findProdutoExist($params){
        $result = $this->factory->findProdutoExist(array(
            ":NRADQUIRENTE"         => $params["NRADQUIRENTE"],
            ":NRPRODUTOADQ"         => $params["NRPRODUTOADQ"],
            ":NRORG"                => $params["NRORG"]
            ));
        return $result;
    }
    
    
    public function findEstabelecExist($params){
        $result = $this->factory->findEstabelecExist(array(
            ":NRADQUIRENTE"         => $params["NRADQUIRENTE"],
            ":NRPRODUTOADQ"         => $params["NRPRODUTOADQ"],
            ":NRESTABELEC"          => $params["NRESTABELEC"],
            ":NRORG"                => $params["NRORG"]
            ));
        return $result;
    }
    
    public function filterEstabelec($params){

        $result = $this->factory->filterEstabelec(array(
            ":NRADQUIRENTE"         => $params[0]["value"],
            ":NRPRODUTOADQ"         => $params[1]["value"],
            ":NRORG"                => $params[2]["value"]
            ));
        return $result;
    }

    
    
    public function getTpCredito () {
        $result = $this->factory->getTpCredito();
        return $result;
    }

    public function getTpOper(){
        $result = $this->factory->getTpOper();
        return $result;
    }
    
    public function getContaRec () {
        $result = $this->factory->getContaRec();
        return $result;
    }

    public function getTpAjuste () {
        $result = $this->factory->getTpAjuste();
        return $result;
    }

    public function getTpDebito () {
        $result = $this->factory->getTpDebito();
        return $result;
    }

    public function deleteProduto($params){
        $result = $this->factory->deleteProduto(array(
            ":NRADQUIRENTE"         => $params["NRADQUIRENTE"],
            ":NRPRODUTOADQ"         => $params["NRPRODUTOADQ"],
            ":NRORG"                => $params["NRORG"]
            
        ));
        return $result;
    
	
    }
    
    
    public function deleteEstabelec($params){
        $result = $this->factory->deleteEstabelec(array(
            ":NRPARAMFINADQ"     => $params["NRPARAMFINADQ"],
            ":NRADQUIRENTE"         => $params["NRADQUIRENTE"],
            ":NRPRODUTOADQ"         => $params["NRPRODUTOADQ"],
            ":NRESTABELEC"          => $params["NRESTABELEC"],
            ":NRORG"                => $params["NRORG"]
            
        ));
        return $result;
    
	
    }

    public function deleteEstabelecFromProdutoEdit($params){
        $result = $this->factory->deleteEstabelecFromProdutoEdit(array(
            ":NRADQUIRENTE"         => $params["NRADQUIRENTE"],
            ":NRPRODUTOADQ"         => $params["NRPRODUTOADQANT"],
            ":NRORG"                => $params["NRORG"]
            ));
    }
    
    
    public function getProdutoEstabelec($params){
        $result = $this->factory->getProdutoEstabelec(array(
            ":NRORG"                => $params[0]["value"],
            ":NRADQUIRENTE"         => $params[1]["value"],
            ":NRPRODUTOADQ"         => $params[2]["value"],
            ":ALL_FIELDS"           => isset($params[3]) ? str_replace('%', '', $params[3]["value"][0]['_ALL']) : null,
            ":TALL_FIELDS"          => isset($params[3]) ? 'F' : 'T',
        ));
        return $result;
        
    }
    
}