<?php
namespace Teknisa\CNC\Services;

use Doctrine\DBAL\Connection;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;

class NovoCodigo extends StoredProcedure {

    protected $connection;

	public function __construct(Connection $connection, $procedureName = 'NOVO_CODIGO') {
	    $this->connection = $connection;
		parent::__construct($connection, $procedureName);
	}

	/**
	 * Format a code generated by the new code, making cast to int
	 * or return the value based on column size.
	 *
	 * @param      $code
	 * @param      $colSize
	 * @param bool $castToNumeric
	 *
	 * @return int|string
	 */
	protected function formatValue($code, $colSize, $castToNumeric = false) {
		return $castToNumeric ? (int)$code : substr($code, -1 * $colSize);
	}

	/**
	 * Return a code generated by the procedure
	 *
	 * @param      $tableName
	 * @param      $nrorg
	 * @param int  $interval
	 * @param int  $colSize
	 * @param bool $castToNumeric
	 *
	 * @return int|string
	 */
	public function getCodeByTableName($tableName, $nrorg, $interval = 1, $colSize = 10, $castToNumeric = false) {
		
		$this->addParam(new Param('P_CONTADOR', Param::PARAM_INPUT, $tableName, Param::PARAM_TYPE_STR));
		$this->addParam(new Param('P_SEQUENCIAL', Param::PARAM_OUTPUT, null, Param::PARAM_TYPE_STR, 20));
		$this->addParam(new Param('P_QTDE', Param::PARAM_INPUT, $interval, Param::PARAM_TYPE_INT));
		$this->addParam(new Param('P_NRORG', Param::PARAM_INPUT, $nrorg, Param::PARAM_TYPE_INT));

		$code = $this->execute();

		// clear params
		$this->params = array();

		return $this->formatValue($code['P_SEQUENCIAL'], $colSize, $castToNumeric);

	}

    public static function geraCodigo($connection, $contador, $nrorg, $size =1){
        $procedure = new StoredProcedure($connection, 'NOVO_CODIGO');
        $procedure->addParam(new Param('P_CONTADOR'  , Param::PARAM_INPUT , $contador, Param::PARAM_TYPE_STR    ));
        $procedure->addParam(new Param('P_SEQUENCIAL', Param::PARAM_OUTPUT, null     , Param::PARAM_TYPE_STR, 20));
        $procedure->addParam(new Param('P_QTDE'      , Param::PARAM_INPUT , 1        , Param::PARAM_TYPE_INT    ));
        $procedure->addParam(new Param('P_NRORG'     , Param::PARAM_INPUT , $nrorg   , Param::PARAM_TYPE_INT    ));
        $novocodigo = $procedure->execute();
        $intSeq =  (int)$novocodigo['P_SEQUENCIAL'];
		$intSeq = str_pad($intSeq, $size, "0", STR_PAD_LEFT);  
        return $intSeq;
    }

    public static function geraCodigoVND($connection, $contador, $nrorg,$qtde, $size =1){
        $procedure = new StoredProcedure($connection, 'NOVO_CODIGO');
        $procedure->addParam(new Param('P_CONTADOR'  , Param::PARAM_INPUT , $contador, Param::PARAM_TYPE_STR    ));
        $procedure->addParam(new Param('P_SEQUENCIAL', Param::PARAM_OUTPUT, null     , Param::PARAM_TYPE_STR, 20));
        $procedure->addParam(new Param('P_QTDE'      , Param::PARAM_INPUT , $qtde      , Param::PARAM_TYPE_INT    ));
        $procedure->addParam(new Param('P_NRORG'     , Param::PARAM_INPUT , $nrorg   , Param::PARAM_TYPE_INT    ));
        $novocodigo = $procedure->execute();
        $intSeq =  (int)$novocodigo['P_SEQUENCIAL'];
        return $intSeq;
    }

    public static function geraNovoCodigo($nrorg, $stcodigo, $intervalo = 1, $tamanhoColuna = 10, $numerico = false, $commit = true)
    {
        $novocodigo = self::executaProcedure($stcodigo, $nrorg, $intervalo, $commit);
        return self::preparaValor($novocodigo, $tamanhoColuna, $numerico);
    }

    /**
     * @static
     * @param $novocodigo
     * @param $tamanhoColuna
     * @param $numerico
     * @return int|string
     */
    protected static function preparaValor($novocodigo, $tamanhoColuna, $numerico)
    {
        /**
         * Valor do "$novoCodigo" vem uma string com "left zero fill" de tamanho 20, eg "00000000000012345678";
         * Por isso o casting para int, e o substr, lembrando de um exemplo onde o tamanho � 10:
         * substr($novocodigo, -1*$tamanhoColuna) => substr("00000000000012345678", -10) => "0012345678"
         * Lembrando que ele vai pegar os 10 ultimos digitos e/ou os 10 digitos menos significativos, que s�o os
         * 10 digitos a esquerda.
         */
        return $numerico === true ? (int)$novocodigo :  substr($novocodigo, -1*$tamanhoColuna);
    }

    /**
     * @static
     * @param $stcodigo
     * @param $nrorg
     * @param $intervalo
     * @return mixed
     */
    protected static function executaProcedure($stcodigo, $nrorg, $intervalo, $commit = true)
    {
        // @todo usar o nrorg.
        if($commit) {
            $procedure = new Procedure('NOVO_CODIGO');
        } else {
            $procedure = new Procedure('NOVO_CODIGO_SC');
        }

        $procedure->addParam(new Param('P_CONTADOR', Param::PARAM_INPUT, $stcodigo, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_SEQUENCIAL', Param::PARAM_OUTPUT, null, Param::PARAM_TYPE_STR, 20));
        $procedure->addParam(new Param('P_QTDE', Param::PARAM_INPUT, $intervalo, Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_NRORG', Param::PARAM_INPUT, $nrorg, Param::PARAM_TYPE_INT));
        $novocodigo = $procedure->call();
        return $novocodigo['P_SEQUENCIAL'];
    }
}