<?php 

namespace WebServiceCall\Service;

use WebServiceCall\Log\OutputStreamLogger;

use WebServiceCall\AccessStage\AccessInfo as AccessInfoInterface;

use WebServiceCall\Util\ArrayUtil;

use WebServiceCall\Repository\FileManager\AManager;
use WebServiceCall\Repository\FileManager\ConfigManager;

use WebServiceCall\Service\Interfaces\IToken;

use WebServiceCall\Repository\DB\Token as TokenRepo;

class Token implements IToken {
    private $tokenRepo;
    private $configManager;
    
    public function __construct() {
        $this->tokenRepo = new TokenRepo();
        $this->setConfigManager(new ConfigManager());
    }
    
    private function setConfigManager(AManager $configRepository) {
        $this->configManager = $configRepository;
    }
    
    public function getEstabelecCredentials() {
        $estabelecData = $this->getEstabelecData();
        
        $tokensEmpresas   = $estabelecData['TOKENEMPRESA'];
        $tokensPasswords  = $estabelecData['TOKENSENHA'];
        
        // Merja os arrays em uma única estrutura.
        $accessInfo = ArrayUtil::zipTwo($tokensEmpresas, $tokensPasswords);
        
        // Cria um vetor de objetos com as propriedades idEmpresa e pass
        // Com as credenciais de cada estabelecimento.
        return array_map(function($data) {
            return new AccessInfoInterface($data['COMPANY'], $data['PASSWORD']);
        }, $accessInfo);
    }
    
    private function getEstabelecData() {
        $estabelecData = [];
        
        $shouldReadFromDatabase = $this->shouldReadFromDatabase();
        if ($shouldReadFromDatabase) {
            OutputStreamLogger::log('Os estabelecimentos e suas respectivas empresas serão lidas do banco de dados.');
            $estabelecData = $this->getDataFromDatabase();
        } else {
            OutputStreamLogger::log('Os estabelecimentos e suas respectivas empresas serão lidas do arquivo de configuração (config.json).');
            $estabelecData = $this->getDataFromConfigFile();
        }
        
        return $estabelecData;
    }
    
    private function getDataFromDatabase() {
        $data = $this->tokenRepo->getEstabelecCredentials();
        
        $idsEmpresaConc = explode("|", $data['TOKENEMPRESA']);
        $passwords      = explode("|", $data['TOKENSENHA']);    
            
        // Array pop utilizado para limpar a ultima posição do array que sempre vira como vazia.
        array_pop($idsEmpresaConc);
        array_pop($passwords);
        
        return array(
            'TOKENEMPRESA' => $idsEmpresaConc,
            'TOKENSENHA'   => $passwords,
        );
    }
    
    private function getDataFromConfigFile() {
        $configData = $this->configManager->getData();
        
        $idsEmpresaConc = explode("|", $configData->getEmpresasIds());
        $passwords = explode("|", $configData->getSenhasEmpresas());
        
        return array(
            'TOKENEMPRESA' => $idsEmpresaConc,
            'TOKENSENHA'   => $passwords,
        );
    }
    
    private function shouldReadFromDatabase() {
        $configData = $this->configManager->getData();
        return $configData->shouldReadFromDB();
    }
}